#
# spec file for package htop
#
# Copyright (c) 2012-2014 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           htop
Version:        1.0.3
Release:        2.2
Summary:        Interactive Process Viewer for Linux
License:        GPL-2.0+
Group:          System/Monitoring
Url:            http://hisham.hm/htop/
Source0:        http://hisham.hm/htop/releases/1.0.3/htop-1.0.3.tar.gz
# PATCH-FIX-OPENSUSE htop-libtinfo.patch pascal.bleser@opensuse.org -- Adds linking -ltinfo on > 12.1 (part of ncurses, but only since then, needed for the function napms):
Patch0:         htop-libtinfo.patch
# PATCH-FIX-OPENSUSE htop-fix-incorrect-fsf-address.patch malcolmlewis@opensuse.org -- Update FSF Address in COPYING.
Patch1:         htop-fix-incorrect-fsf-address.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libtool
# not actually needed, but to let the build fail if that package is not available:
BuildRequires:  lsof
BuildRequires:  make
BuildRequires:  python
Requires:       lsof
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?mdkversion} > 0
BuildRequires:  ncursesw-devel
%else
BuildRequires:  ncurses-devel
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
htop is an interactive process viewer for Linux. It aims to be a 'better top':
you can scroll the process list vertically and horizontally, and select a
process to be killed with the arrow keys instead of by typing its process id.

%prep
%setup -q -n "htop-%{version}"
# only apply patch1 on > 12.1, as it requires and causes autoreconf
# to run, which is rather fragile, and unnecessary on older dists anyway
%if 0%{?suse_version} > 1210
%patch0 -p1
autoreconf -fiv
%endif
%patch1 -p1

%build
%configure \
    --enable-taskstats \
%if 0%{?suse_version} == 0 || 0%{?suse_version} >= 1100
    --enable-unicode \
%endif
    --enable-openvz \
    --enable-vserver

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%if 0%{?suse_version}
%suse_update_desktop_file -r "%{name}" System Monitor
%endif

%if 0%{?suse_version} == 0 || 0%{?suse_version} >= 1130
%post
%desktop_database_post
%endif

%if 0%{?suse_version} == 0 || 0%{?suse_version} >= 1130
%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README ChangeLog
%{_bindir}/htop
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/htop.1%{?ext_man}
%{_datadir}/pixmaps/%{name}.png

%changelog
* Tue Apr 29 2014 malcolmlewis@opensuse.org
- Update to 1.0.3:
  + Tag all children ('c' key)
  + Fixes in accounting of guest time when using virtualization
    (thanks to Patrick Marlier).
  + Performance improvements (thanks to Jann Horn).
  + Further performance improvements due to conditional parsing
    of IO data depending on selected fields.
  + Better consistency in coloring.
  + Increase limit of buffer when tracing a deep nested process
    tree.
  + Display pagefault stats.
  + BUGFIX: Fix crash when adding meters and toggling detailed CPU
    time (thanks to Dawid Gajownik).
  + Add column to track the OOM-killer score of processes
    (thanks to Leigh Simpson).
- Rebase htop-libtinfo.patch.
- Add htop-fix-incorrect-fsf-address.patch: Update FSF Address in
  COPYING.
- Spec file clean up.
* Thu Nov  8 2012 pascal.bleser@opensuse.org
- fix build on Mandriva (needs ncursesw-devel instead of ncurses-devel)
* Wed Nov  7 2012 pascal.bleser@opensuse.org
- update to 1.0.2:
  * Add IO priority support ('i' key)
  * Avoid deleting .htoprc if it is a symlink
  * Fail gracefully when /proc is not mounted
  * Option to update process names on every refresh
  * BUGFIX: Fix crashes when process list is empty
* Sun Jul  1 2012 puzel@suse.com
- drop unnecessary build dependency on valgrind-devel
* Fri Feb 17 2012 pascal.bleser@opensuse.org
- add copyright header + changelog trailer
* Fri Feb 17 2012 pascal.bleser@opensuse.org
- update to 1.0.1:
  * fixes the behavior of mouse selection
  * fixes occasional crashes
  * configuration now uses an XDG-compliant path
- changed License: to SPDX
* Mon Nov 21 2011 pascal.bleser@opensuse.org
- add patch to fix linking on factory (> 12.1) as it also requires linking
  libtinfo.so for the function napms
* Mon Nov 21 2011 pascal.bleser@opensuse.org
- update to 1.0:
  * four-column CPU meters
  * incremental filtering
  * UTF-8 tree drawing
  * performance improvements
  * bugfixes
* Sun Nov 28 2010 pascal.bleser@opensuse.org
- update to 0.9.0:
  * adds the ability to expand and collapse subtrees using the + and - keys
  * adds support for steal/guest CPU time measurement for virtualized environments
  * adds the ability to show custom thread names
  * adds support for cgroups
  * adds support for STARTTIME field
  * getopt-based long options and --no-color
  * bugfixes:
    + fix display of nan%% in CPU meters
    + fix memory leak (by Pavol Rusnak)
    + fix IO-wait color in "Black on White" scheme
    + fix search by process name when list is filtered by user
    + fix alignment for display of memory values above 100G (sign of the times!)
  * add Bash/emacs style navigation keys
  * improve battery meter support
* Tue Jun 23 2009 pascal.bleser@opensuse.org
- update to 0.8.3:
  * stability fixes
* Tue Jun  2 2009 pascal.bleser@opensuse.org
- update to 0.8.2:
  * integration with lsof to list files opened by a process
  * a hostname header entry
  * improvements to the battery meter
  * bugfixes
* Mon May  4 2009 pascal.bleser@opensuse.org
- update to SVN revision 151:
  * option to display hostname in the meters area
  * rename VEID to CTID in OpenVZ systems
  * allow compilation without PLPA on systems that don't support it
  * BUGFIX: fix missing tree view when userland threads are hidden
  * BUGFIX: fix for VPID on OpenVZ systems
- enabl openvz and vserver support
* Sun Jan  4 2009 guru@unixtech.be
- added patch to fix CVE-2008-5076:
  " htop 0.7 writes process names to a terminal without sanitizing non-printable characters, which might allow local users to hide processes, modify arbitrary files, or have unspecified other impact via a process name with "crazy control strings.""
* Wed Sep 24 2008 guru@unixtech.be
- added TODO to documentation files
- update to 0.8.1:
  * adds a battery meter for ACPI-enabled computers
  * adds Linux-VServer support
  * some bugfixes
* Thu May  8 2008 guru@unixtech.be
- added Authors:
- new upstream version:
  * adds per-process I/O statistics
  * Unicode support
  * new handling of CPU count for threaded processes: it can now show either
    per-thread stats or a sum of all threads depending whether user threads
    are shown or hidden
  * improvements in mouse support.
* Sat Nov 24 2007 guru@unixtech.be
- new upstream version
* Sat Oct  6 2007 guru@unixtech.be
- moved to openSUSE Build Service
